gchecky.model.address_t

Package gchecky :: Module model :: Class address_t |
[hide private]
[frames] | no frames]

# Class address_t

source code

    object --+
             |
     gxml.Node --+
                 |
                address_t

Known Subclasses:
  billing_address_t, buyer_billing_address_t, buyer_shipping_address_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| address1 = `String:PATH(address1):REQ:EMPTY`
| address2 = `String:PATH(address2):OPT:EMPTY`
| city = `String:PATH(city):REQ:EMPTY`
| company_name = `String:PATH(company-name):OPT:EMPTY`
| contact_name = `String:PATH(contact-name):OPT:EMPTY`
| country_code = `String:PATH(country-code):REQ:EMPTY`
| email = `Email:PATH(email):OPT:EMPTY`
| fax = `Phone:PATH(fax):OPT:EMPTY`
| phone = `Phone:PATH(phone):OPT:EMPTY`
| postal_code = `Zip:PATH(postal-code):REQ:EMPTY`
| region = `String:PATH(region):REQ:EMPTY`
| structured_name = `Node:PATH(structured-name):OPT:{ structured_`...``
| _fields = ``{``'``address1``'``:` String:PATH(address1):REQ:EMPTY`,` `'``addre``...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### structured_name Value:
      Node:PATH(structured-name):OPT:{ structured_name_t }

  ### _fields list of meta-Fields of this class. Value:
      {'address1': String:PATH(address1):REQ:EMPTY,
       'address2': String:PATH(address2):OPT:EMPTY,
       'city': String:PATH(city):REQ:EMPTY,
       'company_name': String:PATH(company-name):OPT:EMPTY,
       'contact_name': String:PATH(contact-name):OPT:EMPTY,
       'country_code': String:PATH(country-code):REQ:EMPTY,
       'email': Email:PATH(email):OPT:EMPTY,
       'fax': Phone:PATH(fax):OPT:EMPTY,
      ...